@@ -1,4 +1,4 @@
-/* $Id: IckleClient.cpp,v 1.95 2002/04/16 21:05:19 barnabygray Exp $
+/* $Id: IckleClient.cpp,v 1.104 2002/04/26 13:10:51 barnabygray Exp $
  *
  * Copyright (C) 2001 Barnaby Gray <barnaby@beedesign.co.uk>.
  *
@@ -62,7 +62,9 @@ using ICQ2000::ContactRef;
 
 IckleClient::IckleClient(int argc, char* argv[])
   : m_message_queue(),
+    m_event_system(m_message_queue),
     gui( m_message_queue ),
+    
 #ifdef GNOME_ICKLE
     applet(m_message_queue),
 #endif
@@ -273,6 +275,9 @@ void IckleClient::loadSettings() {
   g_settings.defaultValueBool("network_override_port", false);
   g_settings.defaultValueBool("network_in_dc", true);
   g_settings.defaultValueBool("network_out_dc", true);
+  g_settings.defaultValueBool("network_use_portrange", false);
+  g_settings.defaultValueUnsignedShort("network_lower_bind_port", 9000, 1, 65535);
+  g_settings.defaultValueUnsignedShort("network_upper_bind_port", 9010, 1, 65535);
 
   /* Default SMTP server settings */
   g_settings.defaultValueBool("network_smtp", true);
@@ -284,8 +289,8 @@ void IckleClient::loadSettings() {
   g_settings.defaultValueBool("message_autoraise", true);
   g_settings.defaultValueBool("message_autoclose", false);
   g_settings.defaultValueUnsignedInt("history_shownr", 10, 1, 255);
-  g_settings.defaultValueString("message_header_font", "-*-*-bold-*-*-*-*-*-*-*-*-*-*-*");
-  g_settings.defaultValueString("message_text_font", "");
+  g_settings.defaultValueString("message_header_font", "-*-helvetica-bold-r-*-*-*-*-*-*-*-*-*-*");
+  g_settings.defaultValueString("message_text_font", "-*-helvetica-medium-r-*-*-*-*-*-*-*-*-*-*");
 
   /* Default size 0 means that we leave it up to the packed widgets to decide size */
   g_settings.defaultValueUnsignedInt("message_box_width", 0, 0, 2000);
@@ -333,6 +338,13 @@ void IckleClient::loadSettings() {
     icqclient.setSMTPServerPort( 0 );
   }
     
+  if (g_settings.getValueBool("network_use_portrange")) {
+    // use a port range
+    icqclient.setUsePortRange( true );
+    icqclient.setPortRangeLowerBound( g_settings.getValueUnsignedShort("network_lower_bind_port") );
+    icqclient.setPortRangeUpperBound( g_settings.getValueUnsignedShort("network_upper_bind_port") );
+  }
+ 
   icqclient.setAcceptInDC( g_settings.getValueBool("network_in_dc") );
   icqclient.setUseOutDC( g_settings.getValueBool("network_out_dc") );
 
@@ -355,8 +367,7 @@ void IckleClient::loadSettings() {
   if (x + width > swidth) x = swidth-width;
   if (y + height > sheight) y = sheight-height;
 
-  gui.set_default_size( width, height );
-  gui.setGeometry(x,y);
+  gui.setGeometry(x, y, width, height);
   
   ContactListView* clist = gui.getContactListView();
   if (clist) {
@@ -416,7 +427,7 @@ void IckleClient::saveSettings() {
   // save contact-specific settings
   for( map<unsigned int, string>::iterator itr = m_settingsmap.begin(); itr != m_settingsmap.end(); ++itr ) {
     ContactRef c = icqclient.getContact( itr->first );
-    if (c.get() != NULL) saveContact( c, itr->second );
+    if (c.get() != NULL) saveContact( c, itr->second, false );
   }
 }
 
@@ -674,7 +685,13 @@ void IckleClient::messageack_cb(ICQ2000::MessageEvent *ev) {
       ostr << "No history object for contact: " << uin;
       SignalLog(ICQ2000::LogEvent::ERROR, ostr.str());
     } else {
-      m_histmap[ev->getContact()->getUIN()]->log(ev, false);
+      History *h = m_histmap[ev->getContact()->getUIN()];
+      try {
+	h->log(ev, false);
+      } catch(runtime_error& e) {
+	// thrown when the history file can't be opened
+	SignalLog(ICQ2000::LogEvent::WARN, e.what());
+      }
     }
 
   }
@@ -757,7 +774,6 @@ void IckleClient::message_cb(ICQ2000::MessageEvent *ev) {
 
   // add to contact list if not on list already
   if (!icqclient.getContactList().exists(ev->getContact()->getUIN())) {
-    cout << "boo" << endl;
     icqclient.addContact(ev->getContact());
     icqclient.fetchDetailContactInfo(ev->getContact());
   }
@@ -777,7 +793,13 @@ void IckleClient::message_cb(ICQ2000::MessageEvent *ev) {
     ostr << "No history object for contact: " << uin;
     SignalLog(ICQ2000::LogEvent::ERROR, ostr.str());
   } else {
-    m_histmap[ev->getContact()->getUIN()]->log(ev, true);
+    History *h = m_histmap[ev->getContact()->getUIN()];
+    try {
+      h->log(ev, true);
+    } catch(runtime_error& e) {
+      // thrown when the history file can't be opened
+      SignalLog(ICQ2000::LogEvent::WARN, e.what());
+    }
   }
   
 }
@@ -864,7 +886,7 @@ MessageEvent* IckleClient::convert_libicq2000_event(ICQ2000::MessageEvent *ev)
 
 void IckleClient::want_auto_resp_cb(ICQ2000::ICQMessageEvent *ev) {
   ContactRef c = ev->getContact();
-  EventSubstituter evs(c);
+  EventSubstituter evs(m_message_queue, c);
   evs << gui.getAutoResponse();
   ev->setAwayMessage(evs.str());
 }
@@ -919,7 +941,7 @@ void IckleClient::contactlist_cb(ICQ2000::ContactListEvent *ev) {
       return;
     }
     
-    saveContact( c, m_settingsmap[c->getUIN()] );
+    saveContact( c, m_settingsmap[c->getUIN()], false );
     
   }
   else if (ev->getType() == ICQ2000::ContactListEvent::UserRemoved) {
@@ -941,7 +963,7 @@ void IckleClient::settings_changed_cb() {
   saveSettings();
 }
 
-void IckleClient::saveContact(ContactRef c, const string& s)
+void IckleClient::saveContact(ContactRef c, const string& s, bool self)
 {
   Settings user;
   user.setValue( "alias", c->getAlias() );
@@ -985,6 +1007,11 @@ void IckleClient::saveContact(ContactRef c, const string& s)
   user.setValue( "last_message_time", c->get_last_message_time() );
   user.setValue( "last_away_msg_check_time", c->get_last_away_msg_check_time() );
 
+  if (!self) {
+    // save history mapping
+    user.setValue( "history_file", m_histmap[c->getUIN()]->getFilename() );
+  }
+  
   try {
     user.save(s);
   } catch(runtime_error& e) {
@@ -994,7 +1021,7 @@ void IckleClient::saveContact(ContactRef c, const string& s)
 
 void IckleClient::saveSelfContact()
 {
-  saveContact( icqclient.getSelfContact(), BASE_DIR + "self.user" );
+  saveContact( icqclient.getSelfContact(), BASE_DIR + "self.user", true );
 }
 
 void IckleClient::loadContact(const string& s, bool self)
@@ -1112,7 +1139,7 @@ void IckleClient::check_pid_file(){
       cerr << "ickle left behind a stale lockfile (" << PID_FILENAME << ")" << endl;
     } else {
       gui.already_running_prompt( PID_FILENAME, pid );
-      exit(1);
+      quit();
     }
   }
 
